@@ -13,9 +13,6 @@ from pydal.tools.tags import Tags
 from py4web.utils.factories import ActionFactory
 from . import settings
 
-#used to validate hcapcha response
-import requests
-
 # #######################################################
 # implement custom loggers form settings.LOGGERS
 # #######################################################
@@ -33,16 +30,6 @@ for item in settings.LOGGERS:
     logger.setLevel(getattr(logging, level.upper(), "DEBUG"))
     logger.addHandler(handler)
 
-# #######################################################
-# create required folders
-# #######################################################
-
-for folder in [settings.DB_FOLDER,
-               settings.T_FOLDER,
-               settings.UPLOAD_FOLDER]:
-    if not os.path.exists(folder):
-        os.mkdir(folder)
-
 # #######################################################
 # connect to db
 # #######################################################
@@ -59,7 +46,6 @@ db = DAL(
 # #######################################################
 cache = Cache(size=1000)
 T = Translator(settings.T_FOLDER)
-flash = Flash()
 
 # #######################################################
 # pick the session type that suits you best
@@ -95,11 +81,16 @@ auth = Auth(session, db, define_tables=False)
 auth.use_username = True
 auth.param.registration_requires_confirmation = settings.VERIFY_EMAIL
 auth.param.registration_requires_approval = settings.REQUIRES_APPROVAL
-auth.allowed_actions = ["all"]
-auth.login_expiration_time = 3600
-auth.password_complexity = {"entropy": 50}
-auth.block_previous_password_num = 3
+auth.param.login_after_registration = settings.LOGIN_AFTER_REGISTRATION
+auth.param.allowed_actions = settings.ALLOWED_ACTIONS
+auth.param.login_expiration_time = 3600
+auth.param.password_complexity = {"entropy": 50}
+auth.param.block_previous_password_num = 3
+auth.param.default_login_enabled = settings.DEFAULT_LOGIN_ENABLED
 auth.define_tables()
+auth.fix_actions()
+
+flash = auth.flash
 
 # #######################################################
 # Configure email sender for auth
@@ -186,7 +177,7 @@ if settings.USE_CELERY:
     from celery import Celery
 
     # to use "from .common import scheduler" and then use it according
-    # to celery docs
+    # to celery docs, examples in tasks.py
     scheduler = Celery(
         "apps.%s.tasks" % settings.APP_NAME, broker=settings.CELERY_BROKER
     )
@@ -202,20 +193,3 @@ auth.enable(uses=(session, T, db), env=dict(T=T))
 # #######################################################
 unauthenticated = ActionFactory(db, session, T, flash, auth)
 authenticated = ActionFactory(db, session, T, flash, auth.user)
-
-
-def hCaptcha(token):
-    
-    # Retrieve token from post data with key 'h-captcha-response'.
-
-    # Build payload with secret key and token.
-    data = { 'secret': settings.HCAPTCHA_SECRET_KEY, 'response': token }
-
-    # Make POST request with data payload to hCaptcha API endpoint.
-    response = requests.post(url=settings.HCAPTCHA_VERIFY_URL, data=data)
-
-    # Parse JSON from response. Check for success or error codes.
-    response_json = response.json()
-    success = response_json['success']
-
-    return success
\ No newline at end of file
