@@ -1,21 +1,23 @@
 import copy
-import os
 import json
+import os
 from functools import wraps
+
 import jwt
 from yatl.helpers import TAG
-from py4web import action, URL, request
-from py4web.core import dumps, Session, Fixture
+
+from py4web import URL, action, request
+from py4web.core import Fixture, Session, dumps
 
 
 class Inject(Fixture):
     def __init__(self, **variables):
         self.variables = variables
 
-    def transform(self, output, shared_data=None):
+    def on_success(self, context):
+        output = context["output"]
         if isinstance(output, dict):
             output.update(**self.variables)
-        return output
 
 
 class ActionFactory:
@@ -52,7 +54,7 @@ class ActionFactory:
             if template is None:
                 template = func.__name__ + ".html"
             if template:
-                fixtures.append(template)
+                fixtures.insert(0, template)
             new_func = action.uses(*fixtures)(func)
             action(path, method=method)(new_func)
             return func
